#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_EXPX2_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_EXPX2_HPP_INCLUDED

#include <nt2/exponential/include/functions/scalar/expx2.hpp>

#endif
